==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF71S.sql <==
/****************************************************************************/
/* GF71 ( 画面関連状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2013/09/03 10:23:47                                            */
/****************************************************************************/
CREATE TABLE GF71 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (   1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      varchar           ( 256 )                                       /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     varchar           (  60 )                                       /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     varchar           ( 256 )                                       /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     varchar           (  14 )                                       /*  60 最終更新日   */
 , TAGNAME      varchar           (  30 )                                       /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   varchar           (  30 )                                       /*  90 先画面ID     */
 , HREF         varchar           ( 256 )                                       /* 100 ﾘﾝｸ先URL     */
 , TARGET       varchar           (  10 )                                       /* 110 ﾀｰｹﾞｯﾄ       */
 , CLM          varchar           (  30 )                                       /* 120 項目         */
 , P_KEYS       varchar           ( 500 )                                       /* 130 引数ｷｰ       */
 , P_VALS       varchar           ( 500 )                                       /* 140 引数値       */
 , USEGAMENID   varchar           (  20 )                                       /* 150 画面使用     */
 , USEREDIRECT  varchar           (  20 )                                       /* 160 ﾘﾀﾞｲﾚｸﾄ使用  */
 , TEXT_DATA    text                                                            /* 170 ﾃｷｽﾄ         */
 , FGOMIT       varchar           (   1 )       DEFAULT 0   NOT NULL            /* 180 除外ﾌﾗｸﾞ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者       */
);

==> openGion_dev_5.6.9.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF71S.sql <==
/****************************************************************************/
/* GF71 ( 画面関連状態ﾃｰﾌﾞﾙ )                                               */
/*                                                                          */
/* Created : 2013/09/30 18:24:55                                            */
/****************************************************************************/
CREATE TABLE GF71 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (   1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      varchar           ( 256 )                                       /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     varchar           (  60 )                                       /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     varchar           ( 256 )                                       /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     varchar           (  14 )                                       /*  60 最終更新日   */
 , TAGNAME      varchar           (  30 )                                       /*  80 ﾀｸﾞ名称      */
 , TO_GAMENID   varchar           (  30 )                                       /*  90 先画面ID     */
 , HREF         varchar           ( 256 )                                       /* 100 ﾘﾝｸ先URL     */
 , TARGET       varchar           (  30 )                   NOT NULL            /* 110 ﾀｰｹﾞｯﾄ       */
 , CLM          varchar           (  30 )                                       /* 120 項目         */
 , P_KEYS       varchar           ( 500 )                                       /* 130 引数ｷｰ       */
 , P_VALS       varchar           ( 500 )                                       /* 140 引数値       */
 , USEGAMENID   varchar           (  20 )                                       /* 150 画面使用     */
 , USEREDIRECT  varchar           (  20 )                                       /* 160 ﾘﾀﾞｲﾚｸﾄ使用  */
 , TEXT_DATA    text                                                            /* 170 ﾃｷｽﾄ         */
 , FGOMIT       varchar           (   1 )       DEFAULT 0   NOT NULL            /* 180 除外ﾌﾗｸﾞ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者       */
);
